@@ -23,17 +23,16 @@
 #include <config.h>
 #endif
 
-#include <boost/bind.hpp>
 #include <glibmm/i18n.h>
 #include <gtkmm/alignment.h>
 #include <gtkmm/headerbar.h>
 #include <gtkmm/image.h>
+#include <gtkmm/separator.h>
 #include <gtkmm/separatormenuitem.h>
 #include <gtkmm/stock.h>
 
 #include "debug.hpp"
 #include "iactionmanager.hpp"
-#include "iconmanager.hpp"
 #include "ignote.hpp"
 #include "note.hpp"
 #include "notemanager.hpp"
@@ -65,7 +64,6 @@ namespace gnote {
     settings->signal_changed().connect(sigc::mem_fun(*this, &NoteRecentChanges::on_settings_changed));
 
     set_has_resize_grip(true);
-    set_icon_name(IconManager::GNOTE);
 
     m_search_notes_widget.signal_open_note
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_open_note));
@@ -184,7 +182,7 @@ namespace gnote {
 
     m_window_actions_button = manage(new Gtk::Button);
     image = manage(new Gtk::Image);
-    image->property_icon_name() = "emblem-system-symbolic";
+    image->property_icon_name() = "open-menu-symbolic";
     image->property_icon_size() = GTK_ICON_SIZE_MENU;
     m_window_actions_button->set_image(*image);
     m_window_actions_button->signal_clicked().connect(
@@ -459,7 +457,7 @@ namespace gnote {
     }
   }
 
-  void NoteRecentChanges::set_search_text(const std::string & value)
+  void NoteRecentChanges::set_search_text(const Glib::ustring & value)
   {
     m_search_entry.set_text(value);
   }
@@ -661,7 +659,7 @@ namespace gnote {
         .connect(sigc::mem_fun(*this, &NoteRecentChanges::entry_changed_timeout));
     }
 
-    std::string search_text = get_search_text();
+    Glib::ustring search_text = get_search_text();
     if(search_text.empty()) {
       SearchableItem *searchable_widget = dynamic_cast<SearchableItem*>(currently_embedded());
       if(searchable_widget) {
@@ -687,7 +685,7 @@ namespace gnote {
     if(!m_search_box.get_visible()) {
       return;
     }
-    std::string search_text = get_search_text();
+    Glib::ustring search_text = get_search_text();
     if(search_text.empty()) {
       return;
     }
@@ -698,9 +696,9 @@ namespace gnote {
     }
   }
 
-  std::string NoteRecentChanges::get_search_text()
+  Glib::ustring NoteRecentChanges::get_search_text()
   {
-    std::string text = m_search_entry.get_text();
+    Glib::ustring text = m_search_entry.get_text();
     text = sharp::string_trim(text);
     return text;
   }
@@ -765,10 +763,11 @@ namespace gnote {
   {
     std::map<Glib::ustring, Gtk::Widget*> submenus;
     Gtk::PopoverMenu *menu = manage(new Gtk::PopoverMenu);
-    Gtk::Grid *main_grid = manage(new Gtk::Grid);
-    int main_top = 0;
-    int top = 0;
-    Gtk::Grid *grid = manage(utils::create_popover_inner_grid(&top));
+    Gtk::Box *menu_box = manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL));
+    menu_box->property_margin_bottom() = 5;
+    menu_box->property_margin_top() = 5;
+    menu_box->property_margin_left() = 5;
+    menu_box->property_margin_right() = 5;
     FOREACH(Gtk::Widget *item, items) {
       if(item) {
         utils::PopoverSubmenu *submenu = dynamic_cast<utils::PopoverSubmenu*>(item);
@@ -776,27 +775,21 @@ namespace gnote {
           submenus[submenu->name()] = item;
         }
         else {
-          grid->attach(*manage(item), 0, top++, 1, 1);
+          menu_box->add(*manage(item));
         }
       }
       else {
-        main_grid->attach(*grid, 0, main_top++, 1, 1);
-        grid = manage(utils::create_popover_inner_grid(&top));
+        menu_box->add(*manage(new Gtk::Separator));
       }
     }
 
-    if(top > 0) {
-      main_grid->attach(*grid, 0, main_top++, 1, 1);
-      grid = manage(utils::create_popover_inner_grid(&top));
-    }
-
+    menu_box->add(*manage(new Gtk::Separator));
     Gtk::Widget *close_item = manage(utils::create_popover_button("win.close-window", _("_Close")));
     close_item->add_accelerator("activate", get_accel_group(), GDK_KEY_W, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
     close_item->add_accelerator("activate", get_accel_group(), GDK_KEY_Q, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
-    grid->attach(*close_item, 0, top++, 1, 1);
+    menu_box->add(*close_item);
 
-    main_grid->attach(*grid, 0, main_top++, 1, 1);
-    menu->add(*main_grid);
+    menu->add(*menu_box);
     for(auto & submenu : submenus) {
       menu->add(*submenu.second);
       menu->child_property_submenu(*submenu.second) = submenu.first;
@@ -807,7 +800,7 @@ namespace gnote {
     return menu;
   }
 
-  void NoteRecentChanges::on_embedded_name_changed(const std::string & name)
+  void NoteRecentChanges::on_embedded_name_changed(const Glib::ustring & name)
   {
     set_title(name);
   }
