@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2013 Aurimas Cernius
+ * Copyright (C) 2012-2013,2017 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,8 +18,6 @@
  */
 
 
-#include <boost/format.hpp>
-
 #include "isyncmanager.hpp"
 #include "preferences.hpp"
 #include "sharp/uuid.hpp"
@@ -38,9 +36,9 @@ SyncLockInfo::SyncLockInfo()
 {
 }
 
-std::string SyncLockInfo::hash_string()
+Glib::ustring SyncLockInfo::hash_string()
 {
-  return str(boost::format("%1%-%2%-%3%-%4%-%5%") % transaction_id % client_id % renew_count % duration.string() % revision);
+  return Glib::ustring::compose("%1-%2-%3-%4-%5", transaction_id, client_id, renew_count, duration.string(), revision);
 }
 
 
